@@ -36,7 +36,6 @@
 #include "ephy-settings.h"
 #include "ephy-snapshot-service.h"
 #include "ephy-uri-tester-shared.h"
-#include "ephy-view-source-handler.h"
 #include "ephy-web-app-utils.h"
 #include "ephy-web-extension-proxy.h"
 
@@ -63,7 +62,6 @@ typedef struct {
   EphyDownloadsManager *downloads_manager;
   EphyPermissionsManager *permissions_manager;
   EphyAboutHandler *about_handler;
-  EphyViewSourceHandler *source_handler;
   guint update_overview_timeout_id;
   guint hiding_overview_item;
   GDBusServer *dbus_server;
@@ -117,7 +115,6 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->print_settings);
   g_clear_object (&priv->global_history_service);
   g_clear_object (&priv->about_handler);
-  g_clear_object (&priv->source_handler);
   g_clear_object (&priv->user_content);
   g_clear_object (&priv->downloads_manager);
   g_clear_object (&priv->permissions_manager);
@@ -561,15 +558,6 @@ about_request_cb (WebKitURISchemeRequest *request,
   ephy_about_handler_handle_request (priv->about_handler, request);
 }
 
-static void
-source_request_cb (WebKitURISchemeRequest *request,
-                   EphyEmbedShell         *shell)
-{
-  EphyEmbedShellPrivate *priv = ephy_embed_shell_get_instance_private (shell);
-
-  ephy_view_source_handler_handle_request (priv->source_handler, request);
-}
-
 static void
 ephy_resource_request_cb (WebKitURISchemeRequest *request)
 {
@@ -952,12 +940,6 @@ ephy_embed_shell_startup (GApplication *application)
   webkit_security_manager_register_uri_scheme_as_local (webkit_web_context_get_security_manager (priv->web_context),
                                                         EPHY_ABOUT_SCHEME);
 
-  /* view source handler */
-  priv->source_handler = ephy_view_source_handler_new ();
-  webkit_web_context_register_uri_scheme (priv->web_context, EPHY_VIEW_SOURCE_SCHEME,
-                                          (WebKitURISchemeRequestCallback)source_request_cb,
-                                          shell, NULL);
-
   /* ephy-resource handler */
   webkit_web_context_register_uri_scheme (priv->web_context, "ephy-resource",
                                           (WebKitURISchemeRequestCallback)ephy_resource_request_cb,
