@@ -24,7 +24,7 @@
 #include <webkit2/webkit2.h>
 #include "ephy-downloads-manager.h"
 #include "ephy-history-service.h"
-#include "ephy-hosts-manager.h"
+#include "ephy-permissions-manager.h"
 
 G_BEGIN_DECLS
 
@@ -43,9 +43,6 @@ typedef enum
   EPHY_EMBED_SHELL_MODE_SEARCH_PROVIDER
 } EphyEmbedShellMode;
 
-#define EPHY_EMBED_SHELL_MODE_HAS_PRIVATE_PROFILE(mode) \
-  (mode == EPHY_EMBED_SHELL_MODE_PRIVATE || mode == EPHY_EMBED_SHELL_MODE_INCOGNITO)
-
 struct _EphyEmbedShellClass
 {
   GtkApplicationClass parent_class;
@@ -78,6 +75,6 @@ void               ephy_embed_shell_schedule_thumbnail_update  (EphyEmbedShell
                                                                 EphyHistoryURL   *url);
 WebKitUserContentManager *ephy_embed_shell_get_user_content_manager (EphyEmbedShell *shell);
 EphyDownloadsManager     *ephy_embed_shell_get_downloads_manager    (EphyEmbedShell *shell);
-EphyHostsManager         *ephy_embed_shell_get_hosts_manager        (EphyEmbedShell *shell);
+EphyPermissionsManager   *ephy_embed_shell_get_permissions_manager  (EphyEmbedShell *shell);
 
 G_END_DECLS
