@@ -27,7 +27,6 @@
 #include "ephy-about-handler.h"
 #include "ephy-settings.h"
 #include "ephy-string.h"
-#include "ephy-view-source-handler.h"
 
 #include <string.h>
 #include <glib/gi18n.h>
@@ -293,9 +292,6 @@ ephy_embed_utils_is_no_show_address (const char *address)
     if (g_str_equal (address, do_not_show_address[i]))
       return TRUE;
 
-  if (strstr (address, EPHY_VIEW_SOURCE_SCHEME) == address)
-    return TRUE;
-
   return FALSE;
 }
 
